.. image:: https://travis-ci.org/Oslandia/py3dtiles.svg?branch=master
    :target: https://travis-ci.org/Oslandia/py3dtiles

.. image:: https://badge.fury.io/py/py3dtiles.svg
    :target: https://badge.fury.io/py/py3dtiles

=========
py3dtiles
=========

p3dtiles is a Python tool and library for manipulating `3D Tiles`_.

.. _3D Tiles: https://github.com/AnalyticalGraphicsInc/3d-tiles

**CLI Features**

* Convert pointcloud LAS and XYZ files to a 3D Tiles tileset (tileset.json + pnts files)
* Merge pointcloud 3D Tiles tilesets into one tileset
* Read pnts and b3dm files and print a summary of their contents

**API features**

* Read/write pointcloud (pnts) and batched 3d model format

py3dtiles is distributed under the Apache 2 Licence.

Gitlab repository: https://gitlab.com/Oslandia/py3dtiles

Documentation : 

- master: https://oslandia.gitlab.io/py3dtiles/master
- last stable: https://oslandia.gitlab.io/py3dtiles/

